pygerber package
================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pygerber.parser
   pygerber.renderer
   pygerber.tokens
   pygerber.validators

Submodules
----------

.. toctree::
   :maxdepth: 4

   pygerber.API2D
   pygerber.API3D
   pygerber.cli
   pygerber.constants
   pygerber.coparser
   pygerber.drawing_state
   pygerber.exceptions
   pygerber.mathclasses
   pygerber.tokenizer

Module contents
---------------

.. automodule:: pygerber
   :members:
   :undoc-members:
   :show-inheritance:
